==> gromacs_2018.1.orig.tar.gz: gromacs-2018.1/src/gromacs/utility/nodelete.h <==
/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright (c) 2015, by the GROMACS development team, led by
 * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
 * and including many others, as listed in the AUTHORS file in the
 * top-level source directory and at http://www.gromacs.org.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * http://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at http://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out http://www.gromacs.org.
 */
/*! \libinternal \file
 * \brief
 * Declares no_delete deleter for std::shared_ptr.
 *
 * \author Teemu Murtola <teemu.murtola@gmail.com>
 * \inlibraryapi
 * \ingroup module_utility
 */
#ifndef GMX_UTILITY_NODELETE_H
#define GMX_UTILITY_NODELETE_H

namespace gmx
{

/*! \libinternal \brief
 * Deleter for std::shared_ptr that does nothing.
 *
 * This is useful for cases where a class needs to keep a reference to another
 * class, and optionally also manage the lifetime of that other class.
 * The simplest construct (that does not force all callers to use heap
 * allocation and std::shared_ptr for the referenced class) is to use a
 * single std::shared_ptr to hold that reference, and use no_delete as the
 * deleter if the lifetime is managed externally.
 *
 * \inlibraryapi
 * \ingroup module_utility
 */
template <class T>
struct no_delete
{
    //! Deleter that does nothing.
    void operator()(T *) {}
};

} // namespace gmx

#endif

==> gromacs_2019.1.orig.tar.gz: gromacs-2019.1/src/gromacs/utility/nodelete.h <==
/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright (c) 2015,2018, by the GROMACS development team, led by
 * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
 * and including many others, as listed in the AUTHORS file in the
 * top-level source directory and at http://www.gromacs.org.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * http://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at http://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out http://www.gromacs.org.
 */
/*! \libinternal \file
 * \brief
 * Declares no_delete deleter for std::shared_ptr.
 *
 * \author Teemu Murtola <teemu.murtola@gmail.com>
 * \inlibraryapi
 * \ingroup module_utility
 */
#ifndef GMX_UTILITY_NODELETE_H
#define GMX_UTILITY_NODELETE_H

namespace gmx
{

/*! \libinternal \brief
 * Deleter for std::shared_ptr that does nothing.
 *
 * This is useful for cases where a class needs to keep a reference to another
 * class, and optionally also manage the lifetime of that other class.
 * The simplest construct (that does not force all callers to use heap
 * allocation and std::shared_ptr for the referenced class) is to use a
 * single std::shared_ptr to hold that reference, and use no_delete as the
 * deleter if the lifetime is managed externally.
 *
 * \inlibraryapi
 * \ingroup module_utility
 */
template <class T>
struct no_delete
{
    //! Deleter that does nothing.
    void operator()(T * /*unused*/) {}
};

} // namespace gmx

#endif
